@@ -68,7 +68,9 @@ class Media(ABC):
                 _val = _d.get(col)
                 _mod_d = _d.copy()
                 for _x in excl:
-                    _mod_d.pop(_x)
+                    _not_exist = "~!missing~!"
+                    if _mod_d.get(_x, _not_exist) != _not_exist:
+                        _mod_d.pop(_x)
             # if isinstance(_mod_d, dict):
             #     for _k, _v in group.items():
             #         _mod_d.update({_k: _v})
@@ -225,6 +227,7 @@ class Media(ABC):
         return _rtn
 
     def people(self, person: str = None, uid: str = None, video: str = None, videouid: str = None, count: int = None):
+        _rtn = []
         if uid is not None:
             _rtn = self.get(type="people", uid=[uid], count=count)
         elif person is not None:
